diff --git a/MediaPortal/Source/UI/UiComponents/Configuration/ConfigurationControllers/MultipleEntryListController.cs b/MediaPortal/Source/UI/UiComponents/Configuration/ConfigurationControllers/MultipleEntryListController.cs
index a5e6d7c..b647dbf 100644
--- a/MediaPortal/Source/UI/UiComponents/Configuration/ConfigurationControllers/MultipleEntryListController.cs
+++ b/MediaPortal/Source/UI/UiComponents/Configuration/ConfigurationControllers/MultipleEntryListController.cs
@@ -1,15 +1,39 @@
-﻿using System;
+﻿#region Copyright (C) 2007-2014 Team MediaPortal
+
+/*
+    Copyright (C) 2007-2014 Team MediaPortal
+    http://www.team-mediaportal.com
+
+    This file is part of MediaPortal 2
+
+    MediaPortal 2 is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    MediaPortal 2 is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with MediaPortal 2. If not, see <http://www.gnu.org/licenses/>.
+*/
+
+#endregion
+using System;
 using System.Collections.Generic;
-using System.Net;
-using MediaPortal.Common;
 using MediaPortal.Common.Configuration.ConfigurationClasses;
 using MediaPortal.Common.General;
-using MediaPortal.Common.Localization;
 using MediaPortal.UI.Presentation.DataObjects;
-using MediaPortal.UI.Presentation.UiNotifications;
 
 namespace MediaPortal.UiComponents.Configuration.ConfigurationControllers
 {
+  //TODO: use IPAddressBindingsSetting.DisplayLength and AddressBindingsSetting.DisplayHeight
+
+  /// <summary>
+  /// Configuration controller for the <see cref="MultipleEntryList"/> configuration setting.
+  /// </summary>
   public class MultipleEntryListController : SelectionListController
   {
     #region Protected fields
@@ -43,10 +67,6 @@ namespace MediaPortal.UiComponents.Configuration.ConfigurationControllers
 
     #endregion
 
-    #region Protected fields
-
-    #endregion
-
     protected int FindSelectedIndex()
     {
       int current = 0;
@@ -107,16 +127,7 @@ namespace MediaPortal.UiComponents.Configuration.ConfigurationControllers
       var lines = new List<string>();
       foreach (ListItem item in _items)
       {
-        var ipAddress = item.Labels[KEY_NAME].ToString().Trim();
-        IPAddress ip;
-        if (!IPAddress.TryParse(ipAddress, out ip))
-        {
-          ServiceRegistration.Get<INotificationService>().EnqueueNotification(NotificationType.Error,
-            ServiceRegistration.Get<ILocalization>().ToString("[Settings.General.Connectivity.IPAddressBindings]"),
-            String.Format("The IP address '{0}' is invalid", ipAddress),
-          true);
-        }
-        lines.Add(ipAddress);
+        lines.Add(item.Labels[KEY_NAME].ToString());
       }
       var mel = (MultipleEntryList)_setting;
       mel.Lines = lines;
@@ -134,38 +145,61 @@ namespace MediaPortal.UiComponents.Configuration.ConfigurationControllers
       get { return "dialog_configuration_multipleentrylist"; }
     }
 
+    /// <summary>
+    /// Property object for the <see cref="Value"/> property
+    /// </summary>
     public AbstractProperty ValueProperty
     {
       get { return _valueProperty; }
     }
 
+    /// <summary>
+    /// Property for binding the selected entry text to the UI
+    /// </summary>
     public string Value
     {
       get { return (string)_valueProperty.GetValue(); }
       set { _valueProperty.SetValue(value); }
     }
 
+    /// <summary>
+    /// Property object for the <see cref="IsEntrySelected"/> property
+    /// </summary>
     public AbstractProperty IsEntrySelectedProperty
     {
       get { return _isEntrySelectedProperty; }
     }
 
+    /// <summary>
+    /// Gets if any entry is currently selected
+    /// </summary>
     public bool IsEntrySelected
     {
       get { return (bool)_isEntrySelectedProperty.GetValue(); }
       private set { _isEntrySelectedProperty.SetValue(value); }
     }
 
+    /// <summary>
+    /// Gets if add/remove of entries is allowed
+    /// </summary>
     public bool IsAddRemoveEnabled
     {
+      //TODO: should be defined by the setting object
       get { return true; }
     }
 
+    /// <summary>
+    /// Gets if reordering of the entries is allowed
+    /// </summary>
     public bool IsUpDownEnabled
     {
+      //TODO: should be defined by the setting object
       get { return true; }
     }
 
+    /// <summary>
+    /// Adds a new empty entry
+    /// </summary>
     public void Add()
     {
       ListItem listItem = new ListItem(KEY_NAME, String.Empty);
@@ -175,6 +209,10 @@ namespace MediaPortal.UiComponents.Configuration.ConfigurationControllers
       _items.FireChange();
     }
 
+    /// <summary>
+    /// Removes the selected entry
+    /// </summary>
+    /// <remarks>If no entry is selected, nothing happens.</remarks>
     public void Remove()
     {
       int selectedIndex = FindSelectedIndex();
@@ -199,6 +237,10 @@ namespace MediaPortal.UiComponents.Configuration.ConfigurationControllers
       }
     }
 
+    /// <summary>
+    /// Moves the selected entry up by one.
+    /// </summary>
+    /// <remarks>If no or the 1st entry is selected, nothing happens.</remarks>
     public void Up()
     {
       int selectedIndex = FindSelectedIndex();
@@ -211,6 +253,10 @@ namespace MediaPortal.UiComponents.Configuration.ConfigurationControllers
       }
     }
 
+    /// <summary>
+    /// Moves the selected entry down by one.
+    /// </summary>
+    /// <remarks>If no or the last entry is selected, nothing happens.</remarks>
     public void Down()
     {
       int selectedIndex = FindSelectedIndex();
diff --git a/MediaPortal/Source/UI/UiComponents/SkinBase/Settings/Configuration/General/HttpServerPortSetting.cs b/MediaPortal/Source/UI/UiComponents/SkinBase/Settings/Configuration/General/HttpServerPortSetting.cs
index e1100f2..d41949d 100644
--- a/MediaPortal/Source/UI/UiComponents/SkinBase/Settings/Configuration/General/HttpServerPortSetting.cs
+++ b/MediaPortal/Source/UI/UiComponents/SkinBase/Settings/Configuration/General/HttpServerPortSetting.cs
@@ -1,10 +1,37 @@
-﻿using MediaPortal.Common;
+﻿#region Copyright (C) 2007-2014 Team MediaPortal
+
+/*
+    Copyright (C) 2007-2014 Team MediaPortal
+    http://www.team-mediaportal.com
+
+    This file is part of MediaPortal 2
+
+    MediaPortal 2 is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    MediaPortal 2 is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with MediaPortal 2. If not, see <http://www.gnu.org/licenses/>.
+*/
+
+#endregion
+
+using MediaPortal.Common;
 using MediaPortal.Common.Configuration.ConfigurationClasses;
 using MediaPortal.Common.Services.ResourceAccess.Settings;
 using MediaPortal.UI.Presentation.UiNotifications;
 
 namespace MediaPortal.UiComponents.SkinBase.Settings.Configuration.General
 {
+  /// <summary>
+  /// Configuration wrapper around the <see cref="ServerSettings.HttpServerPort"/> setting.
+  /// </summary>
   public class HttpServerPortSetting : LimitedNumberSelect
   {
     #region Base overrides
@@ -26,6 +53,7 @@ namespace MediaPortal.UiComponents.SkinBase.Settings.Configuration.General
       {
         settings.HttpServerPort = value;
         SettingsManager.Save(settings);
+        //TODO: make notification texts localizable or handle rester notification differently
         ServiceRegistration.Get<INotificationService>().EnqueueNotification(NotificationType.UserInteractionRequired, 
           "Restart required", 
           "A restart of Media Portal is required before the modifications are accepted.", 
diff --git a/MediaPortal/Source/UI/UiComponents/SkinBase/Settings/Configuration/General/IPAddressBindingsSetting.cs b/MediaPortal/Source/UI/UiComponents/SkinBase/Settings/Configuration/General/IPAddressBindingsSetting.cs
index 1ddcbfe..50ce405 100644
--- a/MediaPortal/Source/UI/UiComponents/SkinBase/Settings/Configuration/General/IPAddressBindingsSetting.cs
+++ b/MediaPortal/Source/UI/UiComponents/SkinBase/Settings/Configuration/General/IPAddressBindingsSetting.cs
@@ -1,12 +1,40 @@
-﻿using System;
+﻿#region Copyright (C) 2007-2014 Team MediaPortal
+
+/*
+    Copyright (C) 2007-2014 Team MediaPortal
+    http://www.team-mediaportal.com
+
+    This file is part of MediaPortal 2
+
+    MediaPortal 2 is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    MediaPortal 2 is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with MediaPortal 2. If not, see <http://www.gnu.org/licenses/>.
+*/
+
+#endregion
+using System;
+using System.Net;
 using System.Text;
 using MediaPortal.Common;
 using MediaPortal.Common.Configuration.ConfigurationClasses;
+using MediaPortal.Common.Localization;
 using MediaPortal.Common.Services.ResourceAccess.Settings;
 using MediaPortal.UI.Presentation.UiNotifications;
 
 namespace MediaPortal.UiComponents.SkinBase.Settings.Configuration.General
 {
+  /// <summary>
+  /// Configuration wrapper around the <see cref="ServerSettings.IPAddressBindings"/> setting.
+  /// </summary>
   public class IPAddressBindingsSetting : MultipleEntryList
   {
     #region Public Methods
@@ -34,11 +62,21 @@ namespace MediaPortal.UiComponents.SkinBase.Settings.Configuration.General
         var sb = new StringBuilder();
         foreach (var line in _lines)
         {
+          var ipAddress = line.Trim();
+          IPAddress ip;
+          if (!IPAddress.TryParse(ipAddress, out ip))
+          {
+            //TODO: make notification message localizable
+            ServiceRegistration.Get<INotificationService>().EnqueueNotification(NotificationType.Error,
+              ServiceRegistration.Get<ILocalization>().ToString("[Settings.General.Connectivity.IPAddressBindings]"),
+              String.Format("The IP address '{0}' is invalid", ipAddress),
+            true);
+          }
           if (sb.Length > 0)
           {
             sb.Append(',');
           }
-          sb.Append(line.Trim());
+          sb.Append(ipAddress);
         }
         newValue = sb.ToString();
       }
@@ -48,6 +86,7 @@ namespace MediaPortal.UiComponents.SkinBase.Settings.Configuration.General
       {
         settings.IPAddressBindings = newValue;
         SettingsManager.Save(settings);
+        //TODO: make notification texts localizable or handle rester notification differently
         ServiceRegistration.Get<INotificationService>().EnqueueNotification(NotificationType.UserInteractionRequired,
           "Restart required",
           "A restart of Media Portal is required before the modifications are accepted.",
diff --git a/MediaPortal/Source/UI/UiComponents/SkinBase/Settings/Configuration/General/USeIPv6Setting.cs b/MediaPortal/Source/UI/UiComponents/SkinBase/Settings/Configuration/General/USeIPv6Setting.cs
index 6b5859b..031bf19 100644
--- a/MediaPortal/Source/UI/UiComponents/SkinBase/Settings/Configuration/General/USeIPv6Setting.cs
+++ b/MediaPortal/Source/UI/UiComponents/SkinBase/Settings/Configuration/General/USeIPv6Setting.cs
@@ -1,10 +1,36 @@
-﻿using MediaPortal.Common;
+﻿#region Copyright (C) 2007-2014 Team MediaPortal
+
+/*
+    Copyright (C) 2007-2014 Team MediaPortal
+    http://www.team-mediaportal.com
+
+    This file is part of MediaPortal 2
+
+    MediaPortal 2 is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    MediaPortal 2 is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with MediaPortal 2. If not, see <http://www.gnu.org/licenses/>.
+*/
+
+#endregion
+using MediaPortal.Common;
 using MediaPortal.Common.Configuration.ConfigurationClasses;
 using MediaPortal.Common.Services.ResourceAccess.Settings;
 using MediaPortal.UI.Presentation.UiNotifications;
 
 namespace MediaPortal.UiComponents.SkinBase.Settings.Configuration.General
 {
+  /// <summary>
+  /// Configuration wrapper around the <see cref="ServerSettings.UseIPv6"/> setting.
+  /// </summary>
   public class UseIPv6Setting : YesNo
   {
     #region Public Methods
@@ -21,6 +47,7 @@ namespace MediaPortal.UiComponents.SkinBase.Settings.Configuration.General
       {
         settings.UseIPv6 = _yes;
         SettingsManager.Save(settings);
+        //TODO: make notification texts localizable or handle rester notification differently
         ServiceRegistration.Get<INotificationService>().EnqueueNotification(NotificationType.UserInteractionRequired,
           "Restart required",
           "A restart of Media Portal is required before the modifications are accepted.",
diff --git a/MediaPortal/Source/UI/UiComponents/SkinBase/Settings/Configuration/General/UseIPv4Setting.cs b/MediaPortal/Source/UI/UiComponents/SkinBase/Settings/Configuration/General/UseIPv4Setting.cs
index eeaa31f..d91df03 100644
--- a/MediaPortal/Source/UI/UiComponents/SkinBase/Settings/Configuration/General/UseIPv4Setting.cs
+++ b/MediaPortal/Source/UI/UiComponents/SkinBase/Settings/Configuration/General/UseIPv4Setting.cs
@@ -1,10 +1,37 @@
-﻿using MediaPortal.Common;
+﻿#region Copyright (C) 2007-2014 Team MediaPortal
+
+/*
+    Copyright (C) 2007-2014 Team MediaPortal
+    http://www.team-mediaportal.com
+
+    This file is part of MediaPortal 2
+
+    MediaPortal 2 is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    MediaPortal 2 is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with MediaPortal 2. If not, see <http://www.gnu.org/licenses/>.
+*/
+
+#endregion
+
+using MediaPortal.Common;
 using MediaPortal.Common.Configuration.ConfigurationClasses;
 using MediaPortal.Common.Services.ResourceAccess.Settings;
 using MediaPortal.UI.Presentation.UiNotifications;
 
 namespace MediaPortal.UiComponents.SkinBase.Settings.Configuration.General
 {
+  /// <summary>
+  /// Configuration wrapper around the <see cref="ServerSettings.UseIPv4"/> setting.
+  /// </summary>
   public class UseIPv4Setting : YesNo
   {
     #region Public Methods
@@ -21,6 +48,7 @@ namespace MediaPortal.UiComponents.SkinBase.Settings.Configuration.General
       {
         settings.UseIPv4 = _yes;
         SettingsManager.Save(settings);
+        //TODO: make notification texts localizable or handle rester notification differently
         ServiceRegistration.Get<INotificationService>().EnqueueNotification(NotificationType.UserInteractionRequired,
           "Restart required",
           "A restart of Media Portal is required before the modifications are accepted.",
